pub fn build_with_standalone_source(file: &Path, source: &str) -> ModuleGraphExpand description
Build a module graph using caller-owned source without discovering package metadata around the entry file.
pub fn build_with_standalone_source(file: &Path, source: &str) -> ModuleGraphBuild a module graph using caller-owned source without discovering package metadata around the entry file.