read_module_source

Function read_module_source 

pub fn read_module_source(path: &Path) -> Option<String>
Return the source for a resolved module path.

Real paths are read from disk. <std>/<module> virtual paths are backed by the embedded stdlib source table, so callers can parse resolved stdlib modules without knowing about the stdlib mirror layout.