pub struct HostCapabilitySurface { /* private fields */ }Expand description
A deterministic set of host capability operations.
Implementations
Sourceimpl HostCapabilitySurface
impl HostCapabilitySurface
pub fn from_pairs<I, C, O>(pairs: I) -> Self
pub fn contains(&self, capability: &str, operation: &str) -> bool
Sourcepub fn from_value(value: &Value) -> Self
pub fn from_value(value: &Value) -> Self
Read the declaration shapes accepted by Harn’s host-operation files.
pub fn extend(&mut self, other: Self)
pub fn operation_pairs(&self) -> impl Iterator<Item = (&str, &str)>
Sourcepub fn missing_from(
&self,
served: &Self,
runtime_installed: &HostCapabilityExemptions,
) -> Vec<HostCapabilityOperation>
pub fn missing_from( &self, served: &Self, runtime_installed: &HostCapabilityExemptions, ) -> Vec<HostCapabilityOperation>
Return each declared operation the host does not serve, except for operations whose handlers are added at runtime.