Crate harn_modules

Crate harn_modules 

Modules

asset_paths
Package-root prompt asset addressing (issue #742).

Structs

DefSite
A resolved definition site within a module.
ModuleGraph
Parsed information for a set of module files.
ReExportConflict
A duplicate or ambiguous re-export inside a single module. Reported by ModuleGraph::re_export_conflicts.

Enums

DefKind
Kind of symbol that can be exported by a module.
WildcardResolution
Wildcard import resolution status for a single importing module.

Functions

build
Build a module graph from a set of files.
resolve_import_path
Resolve an import string relative to the importing file.